==> ejc-outcontract-impl-3.0.0-20220620.120318-85-sources.jar: com/ejianc/foundation/report/vo/OutcontractSignSummaryReportVO.java <==
package com.ejianc.foundation.report.vo;

import java.math.BigDecimal;


/**
 *
 * 承包类型分析
 *
 */
public class OutcontractSignSummaryReportVO {

    private static final long serialVersionUID = 1L;
    
    /*****************项目维度使用start******************/
    private String projectId; //项目
    private String projectName; //项目名称
    /*****************项目维度使用end******************/

    private String company; //公司
    private Integer sumContract; // 合同个数
    private Integer labor; //劳务分包内容
    private Integer major; //劳务分包内容
    private Integer material; //物资采购
    private Integer equipment; //机械租赁
    private Integer turnoverMaterial; //周转材租赁
    private Integer design; //设计勘察
    private Integer consultancy; //咨询服务
    private Integer other;   //其他合同
    //劳务分包方式
    private Integer packLight; //包轻工
    private Integer smallMechanical; //轻工辅料小型机械
    private Integer expandSub; //扩大劳务分包
    private Integer otherform; //其他形式

    //分包方式
    private Integer laborAndMaterials; //包轻工
    private Integer workersAndAuxiliaryMaterials; //包清工辅材
    private Integer otherForms; //其他形式

    //合同价格
    private Integer laborPrice; //劳务分包 按实体工程量对应的固定单价
    private Integer laborArea;  //劳务分包 按建筑面积平米的每平米固定单价
    private Integer laborFixedPrice; //固定单价
    private Integer laborTotalPrice; //固定总价
    private Integer laborQuotaValuation; //定额计价
    private Integer majorPrice; // 专业分包 按实体工程量对应的固定单价
    private Integer rateLower; // 专业分包 按承包合同价款让利费率下浮
    private Integer majorTotalPrice; // 固定总价
    private Integer majorQuotaValuation; // 定额计价
    private Integer materialFixedPrice; // 物资采购 固定单价
    private Integer adjustablePrice; //可调价格
    private Integer equipmentFixedPrice; // 机械租赁 固定单价
    private Integer equipmentOther; //其他
    private Integer turnoverMaterialFixedPrice; // 周转材租赁 固定单价
    private Integer turnoverMaterialOther; // 其他
    private Integer designFixedPrice;// 设计勘察 固定单价
    private Integer designOther;// 其他
    private Integer consultancyFixedPrice;// 咨询服务 固定单价
    private Integer consultancyOther;//  其他
    private Integer otherFixedPrice;// 其他合同 固定单价
    private Integer other1;// 其他

    /**履约状况累计值start**/
    private BigDecimal projectAmount; //月度结算额 工程款额度
    private BigDecimal laborWagesAmount; //劳务工资额度
    private BigDecimal monthlyProjectAmount; //累计结算额 工程款额度
    private BigDecimal monthlyLaborWagesAmount; //劳务工资额度
    private BigDecimal paidProjectPayment;  //累计已付款 工程款部分
    private BigDecimal payLaborSalaries;  //代付劳务工资部分
    private BigDecimal payProjectPayment;  //累计付款比例工程款部分
    private BigDecimal laborPayProportion;  //劳务费支付比例
    /**履约状况累计值start**/

    private Integer sumSubcontractingContent; //分包项目内容合计
    private Integer sumLaborSubcontracteMode; //劳务分包方式合计
    //合同价格形式合计
    private Integer sumLabor; //劳务分包内容
    private Integer sumMajor; //劳务分包内容
    private Integer sumMaterial; //物资采购
    private Integer sumEquipment; //机械租赁
    private Integer sumTurnoverMaterial; //周转材租赁
    private Integer sumDesign; //设计勘察
    private Integer sumConsultancy; //咨询服务
    private Integer sumOther;   //其他合同

    private String pricingForm; //计价形式
    private String subcontractingContent;//分包内容
    private String type; //合同类型
    private String laborSubcontracteMode;

    public Integer getLaborAndMaterials() {
        return laborAndMaterials;
    }

    public void setLaborAndMaterials(Integer laborAndMaterials) {
        this.laborAndMaterials = laborAndMaterials;
    }



    public Integer getOtherForms() {
        return otherForms;
    }

    public void setOtherForms(Integer otherForms) {
        this.otherForms = otherForms;
    }

    public Integer getWorkersAndAuxiliaryMaterials() {
        return workersAndAuxiliaryMaterials;
    }

    public void setWorkersAndAuxiliaryMaterials(Integer workersAndAuxiliaryMaterials) {
        this.workersAndAuxiliaryMaterials = workersAndAuxiliaryMaterials;
    }

    public String getLaborSubcontracteMode() {
        return laborSubcontracteMode;
    }

    public void setLaborSubcontracteMode(String laborSubcontracteMode) {
        this.laborSubcontracteMode = laborSubcontracteMode;
    }

    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }

    public Integer getSumContract() {
        return sumContract;
    }

    public void setSumContract(Integer sumContract) {
        this.sumContract = sumContract;
    }

    public Integer getSumSubcontractingContent() {
        return sumSubcontractingContent;
    }

    public void setSumSubcontractingContent(Integer sumSubcontractingContent) {
        this.sumSubcontractingContent = sumSubcontractingContent;
    }

    public Integer getSumLaborSubcontracteMode() {
        return sumLaborSubcontracteMode;
    }

    public void setSumLaborSubcontracteMode(Integer sumLaborSubcontracteMode) {
        this.sumLaborSubcontracteMode = sumLaborSubcontracteMode;
    }

    public Integer getLabor() {
        return labor;
    }

    public void setLabor(Integer labor) {
        this.labor = labor;
    }

    public Integer getMajor() {
        return major;
    }

    public void setMajor(Integer major) {
        this.major = major;
    }

    public Integer getMaterial() {
        return material;
    }

    public void setMaterial(Integer material) {
        this.material = material;
    }

    public Integer getEquipment() {
        return equipment;
    }

    public void setEquipment(Integer equipment) {
        this.equipment = equipment;
    }

    public Integer getTurnoverMaterial() {
        return turnoverMaterial;
    }

    public void setTurnoverMaterial(Integer turnoverMaterial) {
        this.turnoverMaterial = turnoverMaterial;
    }

    public Integer getDesign() {
        return design;
    }

    public void setDesign(Integer design) {
        this.design = design;
    }

    public Integer getConsultancy() {
        return consultancy;
    }

    public void setConsultancy(Integer consultancy) {
        this.consultancy = consultancy;
    }

    public Integer getOther() {
        return other;
    }

    public void setOther(Integer other) {
        this.other = other;
    }

    public Integer getPackLight() {
        return packLight;
    }

    public void setPackLight(Integer packLight) {
        this.packLight = packLight;
    }

    public Integer getSmallMechanical() {
        return smallMechanical;
    }

    public void setSmallMechanical(Integer smallMechanical) {
        this.smallMechanical = smallMechanical;
    }

    public Integer getExpandSub() {
        return expandSub;
    }

    public void setExpandSub(Integer expandSub) {
        this.expandSub = expandSub;
    }

    public Integer getOtherform() {
        return otherform;
    }

    public void setOtherform(Integer otherform) {
        this.otherform = otherform;
    }

    public Integer getLaborPrice() {
        return laborPrice;
    }

    public void setLaborPrice(Integer laborPrice) {
        this.laborPrice = laborPrice;
    }

    public Integer getLaborArea() {
        return laborArea;
    }

    public void setLaborArea(Integer laborArea) {
        this.laborArea = laborArea;
    }

    public Integer getLaborFixedPrice() {
        return laborFixedPrice;
    }

    public void setLaborFixedPrice(Integer laborFixedPrice) {
        this.laborFixedPrice = laborFixedPrice;
    }

    public Integer getLaborTotalPrice() {
        return laborTotalPrice;
    }

    public void setLaborTotalPrice(Integer laborTotalPrice) {
        this.laborTotalPrice = laborTotalPrice;
    }

    public Integer getLaborQuotaValuation() {
        return laborQuotaValuation;
    }

    public void setLaborQuotaValuation(Integer laborQuotaValuation) {
        this.laborQuotaValuation = laborQuotaValuation;
    }

    public Integer getMajorPrice() {
        return majorPrice;
    }

    public void setMajorPrice(Integer majorPrice) {
        this.majorPrice = majorPrice;
    }

    public Integer getRateLower() {
        return rateLower;
    }

    public void setRateLower(Integer rateLower) {
        this.rateLower = rateLower;
    }

    public Integer getMajorTotalPrice() {
        return majorTotalPrice;
    }

    public void setMajorTotalPrice(Integer majorTotalPrice) {
        this.majorTotalPrice = majorTotalPrice;
    }

    public Integer getMajorQuotaValuation() {
        return majorQuotaValuation;
    }

    public void setMajorQuotaValuation(Integer majorQuotaValuation) {
        this.majorQuotaValuation = majorQuotaValuation;
    }

    public Integer getMaterialFixedPrice() {
        return materialFixedPrice;
    }

    public void setMaterialFixedPrice(Integer materialFixedPrice) {
        this.materialFixedPrice = materialFixedPrice;
    }

    public Integer getAdjustablePrice() {
        return adjustablePrice;
    }

    public void setAdjustablePrice(Integer adjustablePrice) {
        this.adjustablePrice = adjustablePrice;
    }

    public Integer getEquipmentFixedPrice() {
        return equipmentFixedPrice;
    }

    public void setEquipmentFixedPrice(Integer equipmentFixedPrice) {
        this.equipmentFixedPrice = equipmentFixedPrice;
    }

    public Integer getEquipmentOther() {
        return equipmentOther;
    }

    public void setEquipmentOther(Integer equipmentOther) {
        this.equipmentOther = equipmentOther;
    }

    public Integer getTurnoverMaterialFixedPrice() {
        return turnoverMaterialFixedPrice;
    }

    public void setTurnoverMaterialFixedPrice(Integer turnoverMaterialFixedPrice) {
        this.turnoverMaterialFixedPrice = turnoverMaterialFixedPrice;
    }

    public Integer getTurnoverMaterialOther() {
        return turnoverMaterialOther;
    }

    public void setTurnoverMaterialOther(Integer turnoverMaterialOther) {
        this.turnoverMaterialOther = turnoverMaterialOther;
    }

    public Integer getDesignFixedPrice() {
        return designFixedPrice;
    }

    public void setDesignFixedPrice(Integer designFixedPrice) {
        this.designFixedPrice = designFixedPrice;
    }

    public Integer getDesignOther() {
        return designOther;
    }

    public void setDesignOther(Integer designOther) {
        this.designOther = designOther;
    }

    public Integer getConsultancyFixedPrice() {
        return consultancyFixedPrice;
    }

    public void setConsultancyFixedPrice(Integer consultancyFixedPrice) {
        this.consultancyFixedPrice = consultancyFixedPrice;
    }

    public Integer getConsultancyOther() {
        return consultancyOther;
    }

    public void setConsultancyOther(Integer consultancyOther) {
        this.consultancyOther = consultancyOther;
    }

    public Integer getOtherFixedPrice() {
        return otherFixedPrice;
    }

    public void setOtherFixedPrice(Integer otherFixedPrice) {
        this.otherFixedPrice = otherFixedPrice;
    }

    public Integer getOther1() {
        return other1;
    }

    public void setOther1(Integer other1) {
        this.other1 = other1;
    }

    public Integer getSumLabor() {
        return sumLabor;
    }

    public void setSumLabor(Integer sumLabor) {
        this.sumLabor = sumLabor;
    }

    public Integer getSumMajor() {
        return sumMajor;
    }

    public void setSumMajor(Integer sumMajor) {
        this.sumMajor = sumMajor;
    }

    public Integer getSumMaterial() {
        return sumMaterial;
    }

    public void setSumMaterial(Integer sumMaterial) {
        this.sumMaterial = sumMaterial;
    }

    public Integer getSumEquipment() {
        return sumEquipment;
    }

    public void setSumEquipment(Integer sumEquipment) {
        this.sumEquipment = sumEquipment;
    }

    public Integer getSumTurnoverMaterial() {
        return sumTurnoverMaterial;
    }

    public void setSumTurnoverMaterial(Integer sumTurnoverMaterial) {
        this.sumTurnoverMaterial = sumTurnoverMaterial;
    }

    public Integer getSumDesign() {
        return sumDesign;
    }

    public void setSumDesign(Integer sumDesign) {
        this.sumDesign = sumDesign;
    }

    public Integer getSumConsultancy() {
        return sumConsultancy;
    }

    public void setSumConsultancy(Integer sumConsultancy) {
        this.sumConsultancy = sumConsultancy;
    }

    public Integer getSumOther() {
        return sumOther;
    }

    public void setSumOther(Integer sumOther) {
        this.sumOther = sumOther;
    }

    public BigDecimal getProjectAmount() {
        return projectAmount;
    }

    public void setProjectAmount(BigDecimal projectAmount) {
        this.projectAmount = projectAmount;
    }

    public BigDecimal getLaborWagesAmount() {
        return laborWagesAmount;
    }

    public void setLaborWagesAmount(BigDecimal laborWagesAmount) {
        this.laborWagesAmount = laborWagesAmount;
    }

    public BigDecimal getMonthlyProjectAmount() {
        return monthlyProjectAmount;
    }

    public void setMonthlyProjectAmount(BigDecimal monthlyProjectAmount) {
        this.monthlyProjectAmount = monthlyProjectAmount;
    }

    public BigDecimal getMonthlyLaborWagesAmount() {
        return monthlyLaborWagesAmount;
    }

    public void setMonthlyLaborWagesAmount(BigDecimal monthlyLaborWagesAmount) {
        this.monthlyLaborWagesAmount = monthlyLaborWagesAmount;
    }

    public BigDecimal getPaidProjectPayment() {
        return paidProjectPayment;
    }

    public void setPaidProjectPayment(BigDecimal paidProjectPayment) {
        this.paidProjectPayment = paidProjectPayment;
    }

    public BigDecimal getPayLaborSalaries() {
        return payLaborSalaries;
    }

    public void setPayLaborSalaries(BigDecimal payLaborSalaries) {
        this.payLaborSalaries = payLaborSalaries;
    }

    public BigDecimal getPayProjectPayment() {
        return payProjectPayment;
    }

    public void setPayProjectPayment(BigDecimal payProjectPayment) {
        this.payProjectPayment = payProjectPayment;
    }

    public BigDecimal getLaborPayProportion() {
        return laborPayProportion;
    }

    public void setLaborPayProportion(BigDecimal laborPayProportion) {
        this.laborPayProportion = laborPayProportion;
    }

    public String getPricingForm() {
        return pricingForm;
    }

    public void setPricingForm(String pricingForm) {
        this.pricingForm = pricingForm;
    }

    public String getSubcontractingContent() {
        return subcontractingContent;
    }

    public void setSubcontractingContent(String subcontractingContent) {
        this.subcontractingContent = subcontractingContent;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

	public String getProjectId() {
		return projectId;
	}

	public void setProjectId(String projectId) {
		this.projectId = projectId;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}
}

==> ejc-outcontract-impl-3.0.0-20250107.020835-237-sources.jar: com/ejianc/foundation/report/vo/OutcontractSignSummaryReportVO.java <==
package com.ejianc.foundation.report.vo;

import java.math.BigDecimal;


/**
 *
 * 承包类型分析
 *
 */
public class OutcontractSignSummaryReportVO {

    private static final long serialVersionUID = 1L;
    
    /*****************项目维度使用start******************/
    private String projectId; //项目
    private String projectName; //项目名称
    /*****************项目维度使用end******************/

    private String company; //公司
    private Integer sumContract; // 合同个数
    private Integer labor; //劳务分包内容
    private Integer major; //劳务分包内容
    private Integer material; //物资采购
    private Integer equipment; //机械租赁
    private Integer turnoverMaterial; //周转材租赁
    private Integer design; //设计勘察
    private Integer consultancy; //咨询服务
    private Integer other;   //其他合同
    //劳务分包方式
    private Integer packLight; //包轻工
    private Integer smallMechanical; //轻工辅料小型机械
    private Integer expandSub; //扩大劳务分包
    private Integer otherform; //其他形式

    //分包方式
    private Integer laborAndMaterials; //包轻工
    private Integer workersAndAuxiliaryMaterials; //包清工辅材
    private Integer otherForms; //其他形式

    //合同价格
    private Integer laborPrice; //劳务分包 按实体工程量对应的固定单价
    private Integer laborArea;  //劳务分包 按建筑面积平米的每平米固定单价
    private Integer laborFixedPrice; //固定单价
    private Integer laborTotalPrice; //固定总价
    private Integer laborQuotaValuation; //定额计价
    private Integer majorPrice; // 专业分包 按实体工程量对应的固定单价
    private Integer rateLower; // 专业分包 按承包合同价款让利费率下浮
    private Integer majorTotalPrice; // 固定总价
    private Integer majorQuotaValuation; // 定额计价
    private Integer materialFixedPrice; // 物资采购 固定单价
    private Integer adjustablePrice; //可调价格
    private Integer equipmentFixedPrice; // 机械租赁 固定单价
    private Integer equipmentOther; //其他
    private Integer turnoverMaterialFixedPrice; // 周转材租赁 固定单价
    private Integer turnoverMaterialOther; // 其他
    private Integer designFixedPrice;// 设计勘察 固定单价
    private Integer designTotalPrice;// 固定总价
    private Integer designOther;// 其他
    private Integer consultancyFixedPrice;// 咨询服务 固定单价
    private Integer consultancyOther;//  其他
    private Integer otherFixedPrice;// 其他合同 固定单价
    private Integer other1;// 其他

    /**履约状况累计值start**/
    private BigDecimal projectAmount; //月度结算额 工程款额度
    private BigDecimal laborWagesAmount; //劳务工资额度
    private BigDecimal monthlyProjectAmount; //累计结算额 工程款额度
    private BigDecimal monthlyLaborWagesAmount; //劳务工资额度
    private BigDecimal paidProjectPayment;  //累计已付款 工程款部分
    private BigDecimal payLaborSalaries;  //代付劳务工资部分
    private BigDecimal payProjectPayment;  //累计付款比例工程款部分
    private BigDecimal laborPayProportion;  //劳务费支付比例
    /**履约状况累计值start**/

    private Integer sumSubcontractingContent; //分包项目内容合计
    private Integer sumLaborSubcontracteMode; //劳务分包方式合计
    //合同价格形式合计
    private Integer sumLabor; //劳务分包内容
    private Integer sumMajor; //劳务分包内容
    private Integer sumMaterial; //物资采购
    private Integer sumEquipment; //机械租赁
    private Integer sumTurnoverMaterial; //周转材租赁
    private Integer sumDesign; //设计勘察
    private Integer sumConsultancy; //咨询服务
    private Integer sumOther;   //其他合同

    private String pricingForm; //计价形式
    private String subcontractingContent;//分包内容
    private String type; //合同类型
    private String laborSubcontracteMode;

    public Integer getLaborAndMaterials() {
        return laborAndMaterials;
    }

    public void setLaborAndMaterials(Integer laborAndMaterials) {
        this.laborAndMaterials = laborAndMaterials;
    }



    public Integer getOtherForms() {
        return otherForms;
    }

    public void setOtherForms(Integer otherForms) {
        this.otherForms = otherForms;
    }

    public Integer getWorkersAndAuxiliaryMaterials() {
        return workersAndAuxiliaryMaterials;
    }

    public void setWorkersAndAuxiliaryMaterials(Integer workersAndAuxiliaryMaterials) {
        this.workersAndAuxiliaryMaterials = workersAndAuxiliaryMaterials;
    }

    public String getLaborSubcontracteMode() {
        return laborSubcontracteMode;
    }

    public void setLaborSubcontracteMode(String laborSubcontracteMode) {
        this.laborSubcontracteMode = laborSubcontracteMode;
    }

    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }

    public Integer getSumContract() {
        return sumContract;
    }

    public void setSumContract(Integer sumContract) {
        this.sumContract = sumContract;
    }

    public Integer getSumSubcontractingContent() {
        return sumSubcontractingContent;
    }

    public void setSumSubcontractingContent(Integer sumSubcontractingContent) {
        this.sumSubcontractingContent = sumSubcontractingContent;
    }

    public Integer getSumLaborSubcontracteMode() {
        return sumLaborSubcontracteMode;
    }

    public void setSumLaborSubcontracteMode(Integer sumLaborSubcontracteMode) {
        this.sumLaborSubcontracteMode = sumLaborSubcontracteMode;
    }

    public Integer getLabor() {
        return labor;
    }

    public void setLabor(Integer labor) {
        this.labor = labor;
    }

    public Integer getMajor() {
        return major;
    }

    public void setMajor(Integer major) {
        this.major = major;
    }

    public Integer getMaterial() {
        return material;
    }

    public void setMaterial(Integer material) {
        this.material = material;
    }

    public Integer getEquipment() {
        return equipment;
    }

    public void setEquipment(Integer equipment) {
        this.equipment = equipment;
    }

    public Integer getTurnoverMaterial() {
        return turnoverMaterial;
    }

    public void setTurnoverMaterial(Integer turnoverMaterial) {
        this.turnoverMaterial = turnoverMaterial;
    }

    public Integer getDesign() {
        return design;
    }

    public void setDesign(Integer design) {
        this.design = design;
    }

    public Integer getConsultancy() {
        return consultancy;
    }

    public void setConsultancy(Integer consultancy) {
        this.consultancy = consultancy;
    }

    public Integer getOther() {
        return other;
    }

    public void setOther(Integer other) {
        this.other = other;
    }

    public Integer getPackLight() {
        return packLight;
    }

    public void setPackLight(Integer packLight) {
        this.packLight = packLight;
    }

    public Integer getSmallMechanical() {
        return smallMechanical;
    }

    public void setSmallMechanical(Integer smallMechanical) {
        this.smallMechanical = smallMechanical;
    }

    public Integer getExpandSub() {
        return expandSub;
    }

    public void setExpandSub(Integer expandSub) {
        this.expandSub = expandSub;
    }

    public Integer getOtherform() {
        return otherform;
    }

    public void setOtherform(Integer otherform) {
        this.otherform = otherform;
    }

    public Integer getLaborPrice() {
        return laborPrice;
    }

    public void setLaborPrice(Integer laborPrice) {
        this.laborPrice = laborPrice;
    }

    public Integer getLaborArea() {
        return laborArea;
    }

    public void setLaborArea(Integer laborArea) {
        this.laborArea = laborArea;
    }

    public Integer getLaborFixedPrice() {
        return laborFixedPrice;
    }

    public void setLaborFixedPrice(Integer laborFixedPrice) {
        this.laborFixedPrice = laborFixedPrice;
    }

    public Integer getLaborTotalPrice() {
        return laborTotalPrice;
    }

    public void setLaborTotalPrice(Integer laborTotalPrice) {
        this.laborTotalPrice = laborTotalPrice;
    }

    public Integer getLaborQuotaValuation() {
        return laborQuotaValuation;
    }

    public void setLaborQuotaValuation(Integer laborQuotaValuation) {
        this.laborQuotaValuation = laborQuotaValuation;
    }

    public Integer getMajorPrice() {
        return majorPrice;
    }

    public void setMajorPrice(Integer majorPrice) {
        this.majorPrice = majorPrice;
    }

    public Integer getRateLower() {
        return rateLower;
    }

    public void setRateLower(Integer rateLower) {
        this.rateLower = rateLower;
    }

    public Integer getMajorTotalPrice() {
        return majorTotalPrice;
    }

    public void setMajorTotalPrice(Integer majorTotalPrice) {
        this.majorTotalPrice = majorTotalPrice;
    }

    public Integer getMajorQuotaValuation() {
        return majorQuotaValuation;
    }

    public void setMajorQuotaValuation(Integer majorQuotaValuation) {
        this.majorQuotaValuation = majorQuotaValuation;
    }

    public Integer getMaterialFixedPrice() {
        return materialFixedPrice;
    }

    public void setMaterialFixedPrice(Integer materialFixedPrice) {
        this.materialFixedPrice = materialFixedPrice;
    }

    public Integer getAdjustablePrice() {
        return adjustablePrice;
    }

    public void setAdjustablePrice(Integer adjustablePrice) {
        this.adjustablePrice = adjustablePrice;
    }

    public Integer getEquipmentFixedPrice() {
        return equipmentFixedPrice;
    }

    public void setEquipmentFixedPrice(Integer equipmentFixedPrice) {
        this.equipmentFixedPrice = equipmentFixedPrice;
    }

    public Integer getEquipmentOther() {
        return equipmentOther;
    }

    public void setEquipmentOther(Integer equipmentOther) {
        this.equipmentOther = equipmentOther;
    }

    public Integer getTurnoverMaterialFixedPrice() {
        return turnoverMaterialFixedPrice;
    }

    public void setTurnoverMaterialFixedPrice(Integer turnoverMaterialFixedPrice) {
        this.turnoverMaterialFixedPrice = turnoverMaterialFixedPrice;
    }

    public Integer getTurnoverMaterialOther() {
        return turnoverMaterialOther;
    }

    public void setTurnoverMaterialOther(Integer turnoverMaterialOther) {
        this.turnoverMaterialOther = turnoverMaterialOther;
    }

    public Integer getDesignFixedPrice() {
        return designFixedPrice;
    }

    public void setDesignFixedPrice(Integer designFixedPrice) {
        this.designFixedPrice = designFixedPrice;
    }

    public Integer getDesignOther() {
        return designOther;
    }

    public void setDesignOther(Integer designOther) {
        this.designOther = designOther;
    }

    public Integer getConsultancyFixedPrice() {
        return consultancyFixedPrice;
    }

    public void setConsultancyFixedPrice(Integer consultancyFixedPrice) {
        this.consultancyFixedPrice = consultancyFixedPrice;
    }

    public Integer getConsultancyOther() {
        return consultancyOther;
    }

    public void setConsultancyOther(Integer consultancyOther) {
        this.consultancyOther = consultancyOther;
    }

    public Integer getOtherFixedPrice() {
        return otherFixedPrice;
    }

    public void setOtherFixedPrice(Integer otherFixedPrice) {
        this.otherFixedPrice = otherFixedPrice;
    }

    public Integer getOther1() {
        return other1;
    }

    public void setOther1(Integer other1) {
        this.other1 = other1;
    }

    public Integer getSumLabor() {
        return sumLabor;
    }

    public void setSumLabor(Integer sumLabor) {
        this.sumLabor = sumLabor;
    }

    public Integer getSumMajor() {
        return sumMajor;
    }

    public void setSumMajor(Integer sumMajor) {
        this.sumMajor = sumMajor;
    }

    public Integer getSumMaterial() {
        return sumMaterial;
    }

    public void setSumMaterial(Integer sumMaterial) {
        this.sumMaterial = sumMaterial;
    }

    public Integer getSumEquipment() {
        return sumEquipment;
    }

    public void setSumEquipment(Integer sumEquipment) {
        this.sumEquipment = sumEquipment;
    }

    public Integer getSumTurnoverMaterial() {
        return sumTurnoverMaterial;
    }

    public void setSumTurnoverMaterial(Integer sumTurnoverMaterial) {
        this.sumTurnoverMaterial = sumTurnoverMaterial;
    }

    public Integer getSumDesign() {
        return sumDesign;
    }

    public void setSumDesign(Integer sumDesign) {
        this.sumDesign = sumDesign;
    }

    public Integer getSumConsultancy() {
        return sumConsultancy;
    }

    public void setSumConsultancy(Integer sumConsultancy) {
        this.sumConsultancy = sumConsultancy;
    }

    public Integer getSumOther() {
        return sumOther;
    }

    public void setSumOther(Integer sumOther) {
        this.sumOther = sumOther;
    }

    public BigDecimal getProjectAmount() {
        return projectAmount;
    }

    public void setProjectAmount(BigDecimal projectAmount) {
        this.projectAmount = projectAmount;
    }

    public BigDecimal getLaborWagesAmount() {
        return laborWagesAmount;
    }

    public void setLaborWagesAmount(BigDecimal laborWagesAmount) {
        this.laborWagesAmount = laborWagesAmount;
    }

    public BigDecimal getMonthlyProjectAmount() {
        return monthlyProjectAmount;
    }

    public void setMonthlyProjectAmount(BigDecimal monthlyProjectAmount) {
        this.monthlyProjectAmount = monthlyProjectAmount;
    }

    public BigDecimal getMonthlyLaborWagesAmount() {
        return monthlyLaborWagesAmount;
    }

    public void setMonthlyLaborWagesAmount(BigDecimal monthlyLaborWagesAmount) {
        this.monthlyLaborWagesAmount = monthlyLaborWagesAmount;
    }

    public BigDecimal getPaidProjectPayment() {
        return paidProjectPayment;
    }

    public void setPaidProjectPayment(BigDecimal paidProjectPayment) {
        this.paidProjectPayment = paidProjectPayment;
    }

    public BigDecimal getPayLaborSalaries() {
        return payLaborSalaries;
    }

    public void setPayLaborSalaries(BigDecimal payLaborSalaries) {
        this.payLaborSalaries = payLaborSalaries;
    }

    public BigDecimal getPayProjectPayment() {
        return payProjectPayment;
    }

    public void setPayProjectPayment(BigDecimal payProjectPayment) {
        this.payProjectPayment = payProjectPayment;
    }

    public BigDecimal getLaborPayProportion() {
        return laborPayProportion;
    }

    public void setLaborPayProportion(BigDecimal laborPayProportion) {
        this.laborPayProportion = laborPayProportion;
    }

    public String getPricingForm() {
        return pricingForm;
    }

    public void setPricingForm(String pricingForm) {
        this.pricingForm = pricingForm;
    }

    public String getSubcontractingContent() {
        return subcontractingContent;
    }

    public void setSubcontractingContent(String subcontractingContent) {
        this.subcontractingContent = subcontractingContent;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

	public String getProjectId() {
		return projectId;
	}

	public void setProjectId(String projectId) {
		this.projectId = projectId;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

    public Integer getDesignTotalPrice() {
        return designTotalPrice;
    }

    public void setDesignTotalPrice(Integer designTotalPrice) {
        this.designTotalPrice = designTotalPrice;
    }
}
